
“After 17 to 27 months of treatment, both haloperidol- and olanzapine-treated monkeys had an equivalent and highly significant 8% to 11% decrease in fresh brain weight and volume when compared with the sham group.”

.. _bewijs:

MISHANDELING
############

"Gerichte schade toebrenging."

| Antipsychotica zijn antagonisten, medicijnen die receptoren in de hersenen blokkeren. Dit blokkeren is een benadeling van de gezondheid, er treed een verminderde werking op van de neurotransmitter die geblokkeerd word. Dat de arts deze medicijnen inzet voor hun schadelijke werking, maakt het toedienen ervan opzettelijke benadeling van de gezondheid. Er is dus geen sprake van behandeling maar van mishandeling.

| 300.4 Met mishandeling wordt gelijkgesteld opzettelijke benadeling van de gezondheid.

| 304.3 indien het misdrijf wordt gepleegd door toediening van voor het leven of de gezondheid schadelijke stoffen.

DODELIJK
########

"Hoezo schadelijk?"

Antipsychotica zijn levenbedreigend, toedienen brengt de kans op sterven:

| Antipsychotica zijn giftig, zie :ref:`toxic <toxic>`
| Antipsychotica zijn geen medicijn, zie https://vergiftigingen.info

Bijv. clozapine kan de volgende potentieel dodelijk aandoeningen veroorzaken:

| Neutropenia (tekort witte bloedcellen)
| Myocarditis (ontsteking hartspier)
| Cardiomyopathy (ook hartspier)
| Hypotension (lage bloeddruk)
| Bradycardia (trage hartslag)
| Syncope (flauwvallen)
| Cardiac arrest (hartstilstand)
| Neuroleptic Malignant Syndrome (NMS)
| Constipation (dikke darm verstopping)
| Intestinal Obstruction (darm problemen)
| Fecal Impaction (vastzittend stront)
| Paralytic Ileus (ook voedsel vastzittend in de darm)

| Een patient kan door toediening van antipsychotica te maken krijgen met positieve en negatieve symptomen, symptomen van vergiftiging, onthoudingsverschijnselen en ernstige bijwerkingen, zie :ref:`symptomen`.

SCHADELIJK
##########

"Hoezo dodelijk ?"

Schade zijn de volgende ziektes veroorzaakt door antipsychotica:

| Akathisia
| Katatonie
| Tardieve Dyskinesie
| Extrapiramidale symptomen
| Karakterveranderingen
| Coma
| Parkinsonisme
| Dementie
| Diabetes
| Hersenweefselverlies - http://www.ncbi.nlm.nih.gov/pmc/articles/PMC3476840/

SEDEREN
#######

"Intoxicaties met antipsychotica geven vaak aanleiding tot depressie van het centraal zenuwstelsel (CZS), zich in eerste instantie uitend in sedatie."

Quote van https://vergiftigingen.info, zoek bijv. Zyprexa

Sederen om gevaar te weren, is vergiftiging van de hersenen om tot een depressie van het CZS zodat men in een toestand van sedatie terecht komt.
Een depressie van het centrale zenuwstelsel kan men een benadeling van de gezondheid noemen, men kan het ook een bedreiging op het leven benoemen.
